<?php namespace TierPricingTable\Admin;

use TierPricingTable\Addons\GlobalTieredPricing\CPT\GlobalTieredPricingCPT;
use TierPricingTable\Admin\ProductManagers\ProductManager;
use TierPricingTable\Core\ServiceContainerTrait;
use TierPricingTable\Settings\Settings;
use TierPricingTable\TierPricingTablePlugin;
use TierPricingTable\Admin\ProductManagers\SimpleProductManager;
use TierPricingTable\Admin\ProductManagers\VariationProductManager;
use TierPricingTable\Admin\Export\Woocommerce as WooCommerceExport;
use TierPricingTable\Admin\Import\Woocommerce as WooCommerceImport;
use TierPricingTable\Admin\Import\WPAllImport;

/**
 * Class Admin
 *
 * @package TierPricingTable\Admin
 */
class Admin {

	use ServiceContainerTrait;

	/**
	 * Array of Managers
	 *
	 * @var array
	 */
	private $managers;

	/**
	 * Admin constructor.
	 *
	 * Register menu items and handlers
	 *
	 */
	public function __construct() {

		new ProductManager();
		new VariationProductManager();
		new WooCommerceExport();
		new WooCommerceImport();

		add_action( 'admin_enqueue_scripts', array( $this, 'enqueueAssets' ), 10, 2 );

		if ( 'yes' === get_transient( 'tiered_pricing_table_activated' ) ) {
			add_action( 'admin_notices', array( $this, 'showActivationMessage' ) );
		}
	}

	/**
	 * Show message about activation plugin and advise next step
	 */
	public function showActivationMessage() {
		$link = $this->getContainer()->getSettings()->getLink();

		$this->getContainer()->getFileManager()->includeTemplate( 'admin/alerts/activation-alert.php', array(
			'link'             => $link,
			'documentationURL' => TierPricingTablePlugin::getDocumentationURL(),
			'settingsURL'      => $this->getContainer()->getSettings()->getLink()
		) );

		delete_transient( 'tiered_pricing_table_activated' );
	}

	/**
	 * Register assets on product create/update page
	 *
	 * @param $page
	 */
	public function enqueueAssets( $page ) {

		wp_enqueue_script( 'tiered-pricing-table-admin-js', $this->getContainer()->getFileManager()->locateJSAsset( 'admin/main' ),
			array( 'jquery' ), TierPricingTablePlugin::VERSION );
		wp_enqueue_style( 'tiered-pricing-table-admin-css', $this->getContainer()->getFileManager()->locateAsset( 'admin/style.css' ),
			array(), TierPricingTablePlugin::VERSION );
	}
}
