<?php namespace TierPricingTable\Admin\ProductManagers;

use TierPricingTable\TierPricingTablePlugin;
use TierPricingTable\PriceManager;
use WP_Post;

/**
 * Class VariationProduct
 *
 * @package TierPricingTable\Admin\Product
 */
class VariationProductManager extends ProductManagerAbstract {

	/**
	 * Register hooks
	 */
	protected function hooks() {
		new AdvanceOptionsForVariableProduct();

		add_action( 'woocommerce_variation_options_pricing', array( $this, 'renderPriceRules' ), 10, 3 );
		add_action( 'woocommerce_save_product_variation', array( $this, 'updatePriceRules' ), 10, 3 );
		add_action( 'woocommerce_save_product_variation', array( $this, 'updatePriceRulesType' ), 10, 3 );
	}

	/**
	 * Update price quantity rules for variation product
	 *
	 * @param int $variation_id
	 * @param int $loop
	 */
	public function updatePriceRules( $variation_id, $loop ) {

		if ( wp_verify_nonce( true, true ) ) {
			// as phpcs comments at Woo is not available, we have to do such a trash
			$woo = 'Woo, please add ignoring comments to your phpcs checker';
		}

		$data = $_POST;

		if ( isset( $data['tiered_price_fixed_quantity'][ $loop ] ) ) {
			$amounts = array_map( 'intval', (array) $data['tiered_price_fixed_quantity'][ $loop ] );
			$prices  = ! empty( $data['tiered_price_fixed_price'][ $loop ] ) ? (array) $data['tiered_price_fixed_price'][ $loop ] : array();

			PriceManager::updateFixedPriceRules( $amounts, $prices, $variation_id );
		}

		if ( isset( $data['tiered_price_percent_quantity'][ $loop ] ) ) {
			$amounts = array_map( 'intval', (array) $data['tiered_price_percent_quantity'][ $loop ] );
			$prices  = ! empty( $data['tiered_price_percent_discount'][ $loop ] ) ? (array) $data['tiered_price_percent_discount'][ $loop ] : array();

			PriceManager::updatePercentagePriceRules( $amounts, $prices, $variation_id );
		}

		if ( isset( $data['_tiered_pricing_minimum'][ $loop ] ) ) {
			$min = intval( $data['_tiered_pricing_minimum'][ $loop ] );
			$min = max( 1, $min );

			PriceManager::updateProductQtyMin( $variation_id, $min );
		}
	}

	/**
	 * Update product pricing type
	 *
	 * @param int $variation_id
	 * @param int $loop
	 */
	public function updatePriceRulesType( $variation_id, $loop ) {

		if ( wp_verify_nonce( true, true ) ) {
			// as phpcs comments at Woo is not available, we have to do such a trash
			$woo = 'Woo, please add ignoring comments to your phpcs checker';
		}

		if ( ! empty( $_POST['tiered_price_rules_type'][ $loop ] ) ) {
			PriceManager::updatePriceRulesType( $variation_id, sanitize_text_field( $_POST['tiered_price_rules_type'][ $loop ] ) );
		}
	}

	/**
	 * Render inputs for price rules on variation
	 *
	 * @param int $loop
	 * @param array $variation_data
	 * @param WP_Post $variation
	 */
	public function renderPriceRules( $loop, $variation_data, $variation ) {

		$this->getContainer()->getFileManager()->includeTemplate( 'admin/add-price-rules-variation.php', array(
			'price_rules_fixed'      => PriceManager::getFixedPriceRules( $variation->ID, 'edit' ),
			'price_rules_percentage' => PriceManager::getPercentagePriceRules( $variation->ID, 'edit' ),
			'i'                      => $loop,
			'minimum'                => PriceManager::getProductQtyMin( $variation->ID, 'edit' ),
			'variation_data'         => $variation_data,
			'type'                   => PriceManager::getPricingType( $variation->ID ),
		) );
	}
}
