<?php namespace TierPricingTable\Integrations\Plugins;

use TierPricingTable\PricingRule;

class AeliaMulticurrency extends PluginIntegrationAbstract {

	public function run() {
		add_filter( 'tiered_pricing_table/price/pricing_rule', function ( PricingRule $pricingRule ) {

			// Break if Aelia multicurrency is not installed
			if ( ! has_action( 'wc_aelia_cs_convert' ) ) {
				return $pricingRule;
			}

			$from_currency = get_option( 'woocommerce_currency' );
			$to_currency   = get_woocommerce_currency();

			if ( $pricingRule->isFixed() ) {
				$_rules = array();

				foreach ( $pricingRule->getRules() as $quantity => $price ) {

					/**
					 * Aelia multicurrency hook to convert the prices between currencies
					 *
					 * @since 3.0.0
					 */
					$_rules[ $quantity ] = apply_filters( 'wc_aelia_cs_convert', $price, $from_currency, $to_currency );
				}

				$pricingRule->setRules( $_rules );
			}

			return $pricingRule;

		}, 9999, 2 );
	}

	public function getTitle() {
		return __( 'Aelia Multicurrency', 'tier-pricing-table' );
	}

	public function getDescription() {
		return __( 'Integration provides compatibility with Aelia Multicurrency to properly work with multiple currencies.', 'tier-pricing-table' );
	}

	public function getSlug() {
		return 'aelia-multicurrency';
	}

	public function isPluginActive() {
		return true;
	}
}
