<?php namespace TierPricingTable;

class PricingRule {

	protected $minimum;
	protected $rules = array();
	protected $type;
	protected $productId;
	protected $pricingProvider = 'product';

	/**
	 * PricingRule constructor.
	 *
	 * @param $productId
	 */
	public function __construct( $productId ) {
		$this->productId = $productId;
	}

	/**
	 * Get product ID
	 *
	 * @return mixed
	 */
	public function getProductId() {
		return $this->productId;
	}

	/**
	 * Get minimum
	 *
	 * @return int
	 */
	public function getMinimum() {
		return $this->minimum;
	}

	/**
	 * Set minimum
	 *
	 * @param int $minimum
	 */
	public function setMinimum( $minimum ) {
		$this->minimum = intval( $minimum );
	}

	/**
	 * Get tiered pricing rules
	 *
	 * @return array
	 */
	public function getRules() {
		return $this->rules;
	}

	/**
	 * Set tiered pricing rules
	 *
	 * @param array $rules
	 */
	public function setRules( array $rules ) {
		$this->rules = $rules;
	}

	/**
	 * Get tiered pricing type
	 *
	 * @return mixed
	 */
	public function getType() {
		return $this->type;
	}

	/**
	 * Set tiered pricing type
	 *
	 * @param mixed $type
	 */
	public function setType( $type ) {
		$this->type = in_array( $type, array( 'fixed', 'percentage' ) ) ? $type : 'fixed';
	}

	public function isPercentage() {
		return $this->getType() === 'percentage';
	}

	public function isFixed() {
		return $this->getType() === 'fixed';
	}

	/**
	 * Get pricing provider (Product, Role-based, Category rules or Global Pricing Rules)
	 *
	 * @return string
	 */
	public function getPricingProvider() {
		return $this->pricingProvider;
	}

	/**
	 * Set pricing provider
	 *
	 * @param string $pricingProvider
	 */
	public function setPricingProvider( $pricingProvider ) {
		$this->pricingProvider = $pricingProvider;
	}
}
